class Number:
	def add_numbers(num1,num2):
		return num1 + num2

	def subtact_numbers(num1,num2):
		return num1 - num2

	def multy_numbers(num1,num2):
		return num1 * num2

	def divide_numbers(num1,num2):
		return num1 / num2

